@@ -152,7 +152,8 @@ function MOI.Bridges.final_touch(
     bridge::IntegerToZeroOneBridge{T},
     model::MOI.ModelLike,
 ) where {T}
-    ret = MOI.Utilities.get_bounds(model, T, bridge.x)
+    # Type annotation needed for JET
+    ret = MOI.Utilities.get_bounds(model, T, bridge.x)::Tuple{T,T}
     if ret === bridge.last_bounds
         return nothing  # final_touch already called
     elseif ret[1] == typemin(T) || ret[2] == typemax(T)
