@@ -13,7 +13,7 @@ function Base.read!(io::IO, model::Model)
     if !MOI.is_empty(model)
         error("Cannot read model from file as destination model is not empty.")
     end
-    object = JSON3.read(io, Dict{String,Any})
+    object = JSON.parse(io; dicttype = Dict{String,Any})
     file_version = _parse_mof_version(object["version"]::Dict{String,Any})
     if !(file_version in _SUPPORTED_VERSIONS)
         version = _SUPPORTED_VERSIONS[1]
@@ -393,15 +393,12 @@ end
 
 function function_to_moi(
     ::Val{:VectorOfVariables},
-    ::Type{T},
+    ::Type,
     object::Dict,
     name_map::Dict{String,MOI.VariableIndex},
-) where {T}
-    return MOI.VectorOfVariables(
-        MOI.VariableIndex[
-            name_map[variable] for variable::String in object["variables"]
-        ],
-    )
+)
+    variables = [name_map[variable::String] for variable in object["variables"]]
+    return MOI.VectorOfVariables(variables)
 end
 
 function function_to_moi(
