@@ -175,6 +175,57 @@ function _check_dimension(v::AbstractVector, s)
     return
 end
 
+function _reshape(
+    x::AbstractVector,
+    set::Union{
+        MOI.PositiveSemidefiniteConeSquare,
+        MOI.LogDetConeSquare,
+        MOI.RootDetConeSquare,
+    },
+)
+    n = isqrt(length(x))
+    return reshape(x, (n, n))
+end
+
+function _reshape(
+    x::AbstractVector{T},
+    set::Union{
+        MOI.PositiveSemidefiniteConeTriangle,
+        MOI.LogDetConeTriangle,
+        MOI.RootDetConeTriangle,
+    },
+) where {T<:Real}
+    n = isqrt(2 * length(x))
+    # The type annotation is needed for JET.
+    X = zeros(T, n, n)::Matrix{T}
+    k = 1
+    for i in 1:n
+        for j in 1:i
+            X[j, i] = X[i, j] = x[k]
+            k += 1
+        end
+    end
+    return LinearAlgebra.Symmetric(X)
+end
+
+function _reshape(
+    x::AbstractVector{T},
+    set::MOI.PositiveSemidefiniteConeTriangle,
+) where {T<:Complex}
+    n = isqrt(2 * length(x))
+    # The type annotation is needed for JET.
+    X = zeros(T, n, n)::Matrix{T}
+    k = 1
+    for i in 1:n
+        for j in 1:i
+            X[i, j] = conj(x[k])
+            X[j, i] = x[k]
+            k += 1
+        end
+    end
+    return LinearAlgebra.Hermitian(X)
+end
+
 # This is the minimal L2-norm.
 function distance_to_set(
     ::ProjectionUpperBoundDistance,
@@ -499,24 +550,6 @@ function distance_to_set(
     return LinearAlgebra.norm(elements, 2)
 end
 
-function _reshape(x::AbstractVector, set::MOI.PositiveSemidefiniteConeSquare)
-    n = MOI.side_dimension(set)
-    return reshape(x, (n, n))
-end
-
-function _reshape(x::AbstractVector, set::MOI.PositiveSemidefiniteConeTriangle)
-    n = MOI.side_dimension(set)
-    X = zeros(eltype(x), n, n)
-    k = 1
-    for i in 1:n
-        for j in 1:i
-            X[j, i] = X[i, j] = x[k]
-            k += 1
-        end
-    end
-    return LinearAlgebra.Symmetric(X)
-end
-
 """
     distance_to_set(
         ::ProjectionUpperBoundDistance,
@@ -538,7 +571,7 @@ function distance_to_set(
         MOI.PositiveSemidefiniteConeSquare,
         MOI.PositiveSemidefiniteConeTriangle,
     },
-) where {T<:Real}
+) where {T<:Union{Real,Complex}}
     _check_dimension(x, set)
     # We should return the norm of `A` defined by:
     # ```julia
@@ -550,6 +583,180 @@ function distance_to_set(
     # The norm should correspond to `MOI.Utilities.set_dot` so it's the
     # Frobenius norm, which is the Euclidean norm of the vector of eigenvalues.
     eigvals = LinearAlgebra.eigvals(_reshape(x, set))
-    eigvals .= min.(zero(T), eigvals)
-    return LinearAlgebra.norm(eigvals, 2)
+    return LinearAlgebra.norm(min.(0, eigvals), 2)
+end
+
+"""
+    distance_to_set(
+        ::ProjectionUpperBoundDistance,
+        x::AbstractVector{T},
+        set::MOI.VectorNonlinearOracle,
+    ) where {T<:Real}
+
+!!! warning
+    This is not an upper bound on the projection in `x` space; instead, it
+    is a projection in `f(x)`-space.
+"""
+function distance_to_set(
+    ::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.VectorNonlinearOracle{T},
+) where {T<:Real}
+    _check_dimension(x, set)
+    y = zeros(T, set.output_dimension)
+    set.eval_f(y, x)
+    return LinearAlgebra.norm(y .- clamp.(y, set.l, set.u))
+end
+
+# This is the minimal L2-norm.
+function distance_to_set(
+    distance::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.Indicator{MOI.ACTIVATE_ON_ONE},
+) where {T<:Number}
+    _check_dimension(x, set)
+    return min(
+        # Distance of x[1] from 0
+        abs(x[1]),
+        # Distance of x[1] from 1 + distance to set
+        sqrt(abs(1 - x[1])^2 + distance_to_set(distance, x[2], set.set)^2),
+    )
+end
+
+function distance_to_set(
+    distance::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.Indicator{MOI.ACTIVATE_ON_ZERO},
+) where {T<:Number}
+    _check_dimension(x, set)
+    return min(
+        # Distance of x[1] from 1
+        abs(one(T) - x[1]),
+        # Distance of x[1] from 0 + distance to set
+        sqrt(abs(x[1])^2 + distance_to_set(distance, x[2], set.set)^2),
+    )
+end
+
+"""
+    distance_to_set(::ProjectionUpperBoundDistance, x, set::MOI.NormNuclearCone)
+
+Let `(t, y...) = x`. Return the epigraph distance `d` such that `(t + d, y...)`
+belongs to the set.
+"""
+function distance_to_set(
+    ::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.NormNuclearCone,
+) where {T<:Real}
+    _check_dimension(x, set)
+    X = reshape(x[2:end], set.row_dim, set.column_dim)
+    return max(sum(LinearAlgebra.svdvals(X)) - x[1], zero(T))
+end
+
+"""
+    distance_to_set(::ProjectionUpperBoundDistance, x, set::MOI.NormSpectralCone)
+
+Let `(t, y...) = x`. Return the epigraph distance `d` such that `(t + d, y...)`
+belongs to the set.
+"""
+function distance_to_set(
+    ::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.NormSpectralCone,
+) where {T<:Real}
+    _check_dimension(x, set)
+    X = reshape(x[2:end], set.row_dim, set.column_dim)
+    return max(maximum(LinearAlgebra.svdvals(X)) - x[1], zero(T))
+end
+
+"""
+    distance_to_set(
+        ::ProjectionUpperBoundDistance,
+        x::AbstractVector,
+        set::Union{MOI.RootDetConeSquare,MOI.RootDetConeTriangle},
+    )
+
+Let ``Y`` be `y` in `x = (t, y)`, reshaped into the appropriate matrix. The
+returned distance is ``||Y - Z||_2^2`` where ``Z`` is the eigen decomposition of
+``Y`` with negative eigen values removed, plus the epigraph distance in `t`
+needed to satisfy the root-determinant constraint.
+"""
+function distance_to_set(
+    ::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::Union{MOI.RootDetConeSquare,MOI.RootDetConeTriangle},
+) where {T<:Real}
+    _check_dimension(x, set)
+    eigvals = LinearAlgebra.eigvals(_reshape(x[2:end], set))
+    eigvals_neg = min.(zero(T), eigvals)
+    eigvals_pos = max.(zero(T), eigvals)
+    rootdet = prod(eigvals_pos)^(1 / set.side_dimension)
+    push!(eigvals_neg, max(x[1] - rootdet, zero(T)))
+    return LinearAlgebra.norm(eigvals_neg, 2)
+end
+
+"""
+    distance_to_set(
+        ::ProjectionUpperBoundDistance,
+        x::AbstractVector,
+        set::Union{MOI.LogDetConeSquare,MOI.LogDetConeTriangle},
+    )
+
+Let ``Y`` be `y` in `x = (t, y)`, reshaped into the appropriate matrix. The
+returned distance is ``||Y/u - Z||_2^2`` where ``Z`` is the eigen decomposition
+of ``Y`` with negative eigen values removed, plus the epigraph distance in `t`
+needed to satisfy the log-determinant constraint.
+"""
+function distance_to_set(
+    ::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::Union{MOI.LogDetConeSquare,MOI.LogDetConeTriangle},
+) where {T<:Real}
+    _check_dimension(x, set)
+    eigvals = LinearAlgebra.eigvals(_reshape(x[3:end] ./ x[2], set))
+    eigvals_neg = min.(eps(T), eigvals)
+    eigvals_pos = max.(eps(T), eigvals)
+    push!(eigvals_neg, max(x[1] - x[2] * sum(log.(eigvals_pos)), zero(T)))
+    return LinearAlgebra.norm(eigvals_neg, 2)
+end
+
+"""
+    distance_to_set(
+        ::ProjectionUpperBoundDistance,
+        x::AbstractVector,
+        set::MOI.Scaled{S},
+    )
+
+This is the distance in the un-scaled space.
+"""
+function distance_to_set(
+    dist::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.Scaled{S},
+) where {T,S<:MOI.AbstractVectorSet}
+    _check_dimension(x, set)
+    scale = MOI.Utilities.SetDotScalingVector{T}(set.set)
+    return distance_to_set(dist, x ./ scale, set.set)
+end
+
+function distance_to_set(
+    dist::ProjectionUpperBoundDistance,
+    x::AbstractVector{T},
+    set::MOI.HermitianPositiveSemidefiniteConeTriangle,
+) where {T<:Real}
+    _check_dimension(x, set)
+    output_set = MOI.PositiveSemidefiniteConeTriangle(set.side_dimension)
+    y = zeros(Complex{T}, MOI.dimension(output_set))
+    real_offset, imag_offset = 0, length(y)
+    for col in 1:set.side_dimension
+        for row in 1:col
+            real_offset += 1
+            y[real_offset] = x[real_offset]
+            if row != col
+                imag_offset += 1
+                y[real_offset] += x[imag_offset] * im
+            end
+        end
+    end
+    return distance_to_set(dist, y, output_set)
 end
