@@ -92,13 +92,24 @@ mutable struct MatrixOfConstraints{T,AT,BT,ST} <: MOI.ModelLike
     caches::Vector{Any}
     are_indices_mapped::Vector{BitSet}
     final_touch::Bool
-    function MatrixOfConstraints{T,AT,BT,ST}() where {T,AT,BT,ST}
-        model = new{T,AT,BT,ST}(AT(), BT(), ST(), Any[], BitSet[], false)
-        MOI.empty!(model)
+    function MatrixOfConstraints{T}(coefficients, constants, sets) where {T}
+        model = new{T,typeof(coefficients),typeof(constants),typeof(sets)}(
+            coefficients,
+            constants,
+            sets,
+            Any[],
+            BitSet[],
+            false,
+        )
+        _reset_caches!(model)
         return model
     end
 end
 
+function MatrixOfConstraints{T,AT,BT,ST}() where {T,AT,BT,ST}
+    return MatrixOfConstraints{T}(AT(), BT(), ST())
+end
+
 ###
 ### Interface for the .coefficients field
 ###
@@ -292,13 +303,18 @@ function rows end
 
 MOI.is_empty(v::MatrixOfConstraints) = MOI.is_empty(v.sets)
 
-function MOI.empty!(v::MatrixOfConstraints{T}) where {T}
-    MOI.empty!(v.coefficients)
-    empty!(v.constants)
-    MOI.empty!(v.sets)
+function _reset_caches!(v::MatrixOfConstraints{T}) where {T}
     v.caches =
         [Tuple{_affine_function_type(T, S),S}[] for S in set_types(v.sets)]
     v.are_indices_mapped = [BitSet() for _ in eachindex(v.caches)]
+    return
+end
+
+function MOI.empty!(v::MatrixOfConstraints)
+    MOI.empty!(v.coefficients)
+    empty!(v.constants)
+    MOI.empty!(v.sets)
+    _reset_caches!(v)
     v.final_touch = false
     return
 end
