@@ -32,12 +32,12 @@ mutable struct GenericModel{T,O,V,C} <: AbstractModelLike{T}
     # A useful dictionary for extensions to store things. These are
     # _not_ copied between models.
     ext::Dict{Symbol,Any}
-    function GenericModel{T,O,V,C}() where {T,O,V,C}
-        return new{T,O,V,C}(
+    function GenericModel{T}(objective, variables, constraints) where {T}
+        return new{T,typeof(objective),typeof(variables),typeof(constraints)}(
             "",
-            O(),
-            V(),
-            C(),
+            objective,
+            variables,
+            constraints,
             Dict{MOI.VariableIndex,String}(),
             nothing,
             Dict{MOI.ConstraintIndex,String}(),
@@ -47,6 +47,10 @@ mutable struct GenericModel{T,O,V,C} <: AbstractModelLike{T}
     end
 end
 
+function GenericModel{T,O,V,C}() where {T,O,V,C}
+    return GenericModel{T}(O(), V(), C())
+end
+
 abstract type AbstractOptimizer{T} <: MOI.AbstractOptimizer end
 
 """
@@ -291,7 +295,9 @@ function MOI.get(model::AbstractModel, ::Type{MOI.VariableIndex}, name::String)
     if model.name_to_var === nothing
         model.name_to_var = build_name_to_var_map(model.var_to_name)
     end
-    result = get(model.name_to_var, name, nothing)
+    # The type annotation is needed for JET.
+    result =
+        get(model.name_to_var::Dict{String,MOI.VariableIndex}, name, nothing)
     throw_if_multiple_with_name(result, name)
     return result
 end
